ArgMinMaxBlock

Struct ArgMinMaxBlock 

pub struct ArgMinMaxBlock<T: Apply> {
    pub data: BlockData,
    /* private fields */
}
Gets the index of the minimum or maximum value in the input.

For multidimensional inputs, the index returned is the linear index (i.e. the column-major order index).

Linear Index Example

The following 3x5 matrix has each element set to its “linear index”

| 0 | 3 | 6 | 9 | 12 | | 1 | 4 | 7 | 10| 13 | | 2 | 5 | 8 | 11| 14 |

Fields

data: BlockData