pub struct BitwiseOperatorBlock<T>{
pub data: BlockData,
/* private fields */
}Expand description
Performs a bitwise operation on the input values.
Float values are transformed to integers using a floor operation before
the bitwise operation is applied, and then casted back to float before being returned.
This block accepts 2-8 inputs, they must all be the same size/type.
The operation is applied component wise to each element if the input is a matrix.
Fields
data: BlockDataTrait Implementations
Sourceimpl<T> Default for BitwiseOperatorBlock<T>
impl<T> Default for BitwiseOperatorBlock<T>
Sourceimpl<T> ProcessBlock for BitwiseOperatorBlock<T>
impl<T> ProcessBlock for BitwiseOperatorBlock<T>