BytesUnpackBlock

Struct BytesUnpackBlock 

pub struct BytesUnpackBlock<T: Apply> {
    pub data: Vec<BlockData>,
    /* private fields */
}
Unpacks a byte slice into a specified number of outputs based on the provided data types and byte order.

Fields

data: Vec<BlockData>