CompareToValueBlock

Struct CompareToValueBlock 

pub struct CompareToValueBlock<T: Pass> {
    pub data: BlockData,
    /* private fields */
}
Compares the input to a scalar value.

The output is the same size as the input and each element is the result of the comparison.

Fields

data: BlockData