CounterBlock

Struct CounterBlock 

pub struct CounterBlock<T: Apply>
where BlockData: FromPass<T::Counter>,
{ pub data: BlockData, /* private fields */ }
Increments a counter every time the count input is truthy.

The counters can be reset using non-zero values of either a single scalar to to reset all counters or a vector/matrix of values that is the same size as the input to reset individual counters.

The block is generic over a type ‘T’. This is expected to be a tuple of two types, the first is the input type and the second is the reset type. For both types they accepts either a scalar or a matrix of scalars. However they are interpreted as bools or matrices of bools, where true or false is determined by whether the value is non-zero or zero respectively. See the Scalar::is_truthy function for more details.

Fields

data: BlockData