pub struct ExponentBlock<T: Pass + Default> {
pub data: BlockData,
/* private fields */
}Expand description
Raises the input to a specified power (coefficient), and optionally preserves the sign of the input.
It can accept a scalar or a matrix input. If the input is a matrix, the exponentiation is performed element-wise.
The power to raise the input to as well as a flag to optionally preserve the sign of the input when performing the exponentiation can be set in the parameters.
Panics
If the input is negative and the coefficient is < 1.0 and preserve_sign is false, a panic will occur.
Fields
data: BlockDataTrait Implementations
Sourceimpl<S: Scalar + Float + Zero, const NROWS: usize, const NCOLS: usize> ProcessBlock for ExponentBlock<Matrix<NROWS, NCOLS, S>>
impl<S: Scalar + Float + Zero, const NROWS: usize, const NCOLS: usize> ProcessBlock for ExponentBlock<Matrix<NROWS, NCOLS, S>>
Sourceimpl<S: Scalar + Float + Zero> ProcessBlock for ExponentBlock<S>
impl<S: Scalar + Float + Zero> ProcessBlock for ExponentBlock<S>