FrequencyFilterBlock

Struct FrequencyFilterBlock 

pub struct FrequencyFilterBlock<T: Pass> {
    pub data: BlockData,
    /* private fields */
}
Perform a frequency filter operation on a signal, either as a low pass or high pass filter.

The filter is implemented as a first order RC filter. The cutoff frequency and filter type are configurable via paramaters.

This block can accept a scalar or a matrix input. For a matrix input, the filter is applied independently to each element of the matrix.

Fields

data: BlockData