IntegralBlock

Struct IntegralBlock 

pub struct IntegralBlock<T: Apply>
where BlockData: FromPass<T::Output>,
{ pub data: BlockData, /* private fields */ }
Performs a discrete integration of the input signal.

It can accept a scalar or a matrix input, for a matrix input it will do an element wise integration.

Fields

data: BlockData