pub struct MatrixInverseBlock<T: Apply<M>, M: Method> {
pub data: BlockData,
/* private fields */
}Expand description
Inverts a matrix using either a standard inverse or a pseudo-inverse based on the method specified.
This can either attempt to perform a standard matrix inversion on a square matrix, or a pseudo-inverse using SVD for matrices that may or may not be square. The output type of the block is a tuple of (<input_type>, bool), where the bool indicates whether the inversion was successful.
Fields
data: BlockDataTrait Implementations
Sourceimpl<T, M> Default for MatrixInverseBlock<T, M>
impl<T, M> Default for MatrixInverseBlock<T, M>
Sourceimpl<T: Apply<M>, M: Method> IsValid for MatrixInverseBlock<T, M>
impl<T: Apply<M>, M: Method> IsValid for MatrixInverseBlock<T, M>
fn is_valid(&self, _: f64) -> OldBlockData
Sourceimpl<T, M> ProcessBlock for MatrixInverseBlock<T, M>
impl<T, M> ProcessBlock for MatrixInverseBlock<T, M>