pub struct SerialReceiveBlock {
pub data: BlockData,
pub stale_check: StaleTracker,
/* private fields */
}Expand description
Parses incoming serial data by configuring the start / end delimiters and the number of bytes to read.
The is_valid signal will continue to emit true as long as new
data is received before the specified expiration period elapses.
The block caches data until a new message is received and parsed.
Fields
data: BlockDatastale_check: StaleTrackerTrait Implementations
Sourceimpl Default for SerialReceiveBlock
impl Default for SerialReceiveBlock
Sourceimpl IsValid for SerialReceiveBlock
impl IsValid for SerialReceiveBlock
fn is_valid(&self, app_time_s: f64) -> OldBlockData
Sourceimpl ProcessBlock for SerialReceiveBlock
impl ProcessBlock for SerialReceiveBlock