pub struct SerialTransmitBlock<T: Serialize + Pass> {
pub data: BlockData,
/* private fields */
}Expand description
Encodes data for transmission over the serial interface, by prepending the start delimiter and appending the end delimiter to the data.
Data is output as a ByteSliceSignal.
Fields
data: BlockDataTrait Implementations
Sourceimpl<T> Default for SerialTransmitBlock<T>where
T: Serialize + Pass,
impl<T> Default for SerialTransmitBlock<T>where
T: Serialize + Pass,
Sourceimpl<T> ProcessBlock for SerialTransmitBlock<T>where
T: Serialize + Pass,
impl<T> ProcessBlock for SerialTransmitBlock<T>where
T: Serialize + Pass,