pub struct TimerBlock<T> {
pub data: BlockData,
/* private fields */
}Expand description
The Timer block allows timekeeping around discrete events - either by Stopwatch mode or Countdown mode.
The input signal serves as the trigger to start the timer. Any input which is “True” will commence the timer. If the Interruptible option is enabled, the timer will reset every iteration where the input is True. Otherwise, the timer will commence on the first True value. It will then either count down and reset at zero, or count up without ever restarting.
This block is useful for tracking how much time has passed since an event for logical conditions.
Fields
data: BlockDataTrait Implementations
Sourceimpl<T> Default for TimerBlock<T>
impl<T> Default for TimerBlock<T>