pub struct VectorMergeBlock<O, I>where
I: Pass + Mergeable<O>,{
pub data: BlockData,
/* private fields */
}Expand description
Merges vectors and scalars into a single vector.
Vectors are flattened before merging, and the output is a 1xN matrix where N is the sum of the rows*cols of
the inputs. Currently implemented for up to 8 Scalar or Matrix inputs.
Generic arguments:
- <O>: The output type of the block
- <I>: A tuple of inputs that will be merged into the output
Fields
data: BlockDataTrait Implementations
Sourceimpl<O, I> Default for VectorMergeBlock<O, I>
impl<O, I> Default for VectorMergeBlock<O, I>
Sourceimpl<O, I> ProcessBlock for VectorMergeBlock<O, I>
impl<O, I> ProcessBlock for VectorMergeBlock<O, I>