VectorReshapeBlock

Struct VectorReshapeBlock 

pub struct VectorReshapeBlock<I, O> {
    pub data: BlockData,
    /* private fields */
}
Reshapes an input signal to a specified output shape.

If the input type is an (M, N) matrix, the output type MUST have dimensions such that M_inN_in == M_outN_out. Accepts a scalar input, T, if the output is a Matrix<1, 1, T>.

Fields

data: BlockData