VectorSortBlock

Struct VectorSortBlock 

pub struct VectorSortBlock<I, O> {
    pub data: BlockData,
    /* private fields */
}
Sorts all elements of the input signal into a vector output.

If the input type is an (M, N) matrix, the output type MUST be a (1, M*N) matrix or a panic will occur.

This block also accepts scalars, though the output will always be the input.

Fields

data: BlockData