pub struct BytesUnpackBlock<T: Apply> {
pub data: Vec<BlockData>,
/* private fields */
}Expand description
Unpacks a byte slice into a specified number of outputs based on the provided data types and byte order.
Fields
data: Vec<BlockData>Trait Implementations
Sourceimpl<T: Apply> Default for BytesUnpackBlock<T>
impl<T: Apply> Default for BytesUnpackBlock<T>
Sourceimpl<T: Apply> IsValid for BytesUnpackBlock<T>
impl<T: Apply> IsValid for BytesUnpackBlock<T>
fn is_valid(&self, _app_time_s: f64) -> OldBlockData
Sourceimpl<T: Apply> ProcessBlock for BytesUnpackBlock<T>
impl<T: Apply> ProcessBlock for BytesUnpackBlock<T>