pub struct FrequencyFilterBlock<T: Pass> {
pub data: BlockData,
/* private fields */
}Expand description
Perform a frequency filter operation on a signal, either as a low pass or high pass filter.
The filter is implemented as a first order RC filter. The cutoff frequency and filter type are configurable via paramaters.
This block can accept a scalar or a matrix input. For a matrix input, the filter is applied independently to each element of the matrix.
Fields
data: BlockDataTrait Implementations
Sourceimpl<T, const NROWS: usize, const NCOLS: usize> HasIc for FrequencyFilterBlock<Matrix<NROWS, NCOLS, T>>
impl<T, const NROWS: usize, const NCOLS: usize> HasIc for FrequencyFilterBlock<Matrix<NROWS, NCOLS, T>>
fn new(parameters: &Self::Parameters) -> Self
Sourceimpl<T> HasIc for FrequencyFilterBlock<T>
impl<T> HasIc for FrequencyFilterBlock<T>
fn new(parameters: &Self::Parameters) -> Self
Sourceimpl<T, const NROWS: usize, const NCOLS: usize> ProcessBlock for FrequencyFilterBlock<Matrix<NROWS, NCOLS, T>>
impl<T, const NROWS: usize, const NCOLS: usize> ProcessBlock for FrequencyFilterBlock<Matrix<NROWS, NCOLS, T>>
type Inputs = Matrix<NROWS, NCOLS, T>
type Output = Matrix<NROWS, NCOLS, T>
type Parameters = Parameters<Matrix<NROWS, NCOLS, T>, T>
fn process<'b>( &'b mut self, parameters: &Self::Parameters, context: &dyn Context, inputs: PassBy<'_, Self::Inputs>, ) -> PassBy<'b, Self::Output>
Sourceimpl<T> ProcessBlock for FrequencyFilterBlock<T>
impl<T> ProcessBlock for FrequencyFilterBlock<T>