pub struct IntegralBlock<T: Apply>{
pub data: BlockData,
/* private fields */
}Expand description
Performs a discrete integration of the input signal.
It can accept a scalar or a matrix input, for a matrix input it will do an element wise integration.
Fields
data: BlockDataTrait Implementations
Sourceimpl<T: Apply> Default for IntegralBlock<T>
impl<T: Apply> Default for IntegralBlock<T>
Sourceimpl<F: Float, R: Scalar> HasIc for IntegralBlock<(F, R)>
impl<F: Float, R: Scalar> HasIc for IntegralBlock<(F, R)>
fn new(parameters: &Self::Parameters) -> Self
Sourceimpl<F: Float, const NROWS: usize, const NCOLS: usize, R: Scalar> HasIc for IntegralBlock<(Matrix<NROWS, NCOLS, F>, R)>
impl<F: Float, const NROWS: usize, const NCOLS: usize, R: Scalar> HasIc for IntegralBlock<(Matrix<NROWS, NCOLS, F>, R)>
fn new(parameters: &Self::Parameters) -> Self
Sourceimpl<F: Float, R: Scalar> ProcessBlock for IntegralBlock<(F, R)>
impl<F: Float, R: Scalar> ProcessBlock for IntegralBlock<(F, R)>
Sourceimpl<F: Float, const NROWS: usize, const NCOLS: usize, R: Scalar> ProcessBlock for IntegralBlock<(Matrix<NROWS, NCOLS, F>, R)>
impl<F: Float, const NROWS: usize, const NCOLS: usize, R: Scalar> ProcessBlock for IntegralBlock<(Matrix<NROWS, NCOLS, F>, R)>
type Inputs = (Matrix<NROWS, NCOLS, F>, R)
type Output = Matrix<NROWS, NCOLS, F>
type Parameters = Parameters<(Matrix<NROWS, NCOLS, F>, R)>
fn process<'b>( &'b mut self, parameters: &Self::Parameters, context: &dyn Context, inputs: PassBy<'_, Self::Inputs>, ) -> PassBy<'b, Self::Output>