pub struct VectorIndexBlock<const N: usize, T: Scalar, I: Pass>where
[T; N]: TupleEquivalent<T, N>,{
pub data: Vec<BlockData>,
/* private fields */
}Expand description
Extracts a set of values from an input matrix based on the linear index, and outputs them in the order of the indices.
The output of the block matches the order of the indices, for example if the indices are [15, 0], the 0th output of the block will be the 15th element of the input matrix and the 1st output of the block will be the 0th element of the input matrix.
Note: Indices are 0 based and linear. If the indices is output side the bounds of the input matrix, the output will be 0.
Fields
data: Vec<BlockData>Trait Implementations
Sourceimpl<T: Scalar, const N: usize, I: Pass> Default for VectorIndexBlock<N, T, I>where
[T; N]: TupleEquivalent<T, N>,
impl<T: Scalar, const N: usize, I: Pass> Default for VectorIndexBlock<N, T, I>where
[T; N]: TupleEquivalent<T, N>,
Sourceimpl<T: Scalar, const N: usize, const NROWS: usize, const NCOLS: usize> ProcessBlock for VectorIndexBlock<N, T, Matrix<NROWS, NCOLS, T>>where
[T; N]: TupleEquivalent<T, N>,
impl<T: Scalar, const N: usize, const NROWS: usize, const NCOLS: usize> ProcessBlock for VectorIndexBlock<N, T, Matrix<NROWS, NCOLS, T>>where
[T; N]: TupleEquivalent<T, N>,
type Inputs = Matrix<NROWS, NCOLS, T>
type Output = <[T; N] as TupleEquivalent<T, N>>::TupleEquivalent
type Parameters = Parameters<N>
fn process( &mut self, parameters: &Self::Parameters, _context: &dyn Context, inputs: PassBy<'_, Self::Inputs>, ) -> PassBy<'_, Self::Output>