pub struct VectorReshapeBlock<I, O> {
pub data: BlockData,
/* private fields */
}Expand description
Reshapes an input signal to a specified output shape.
If the input type is an (M, N) matrix, the output type MUST have dimensions such that M_inN_in == M_outN_out. Accepts a scalar input, T, if the output is a Matrix<1, 1, T>.
Fields
data: BlockDataTrait Implementations
Sourceimpl<I, O> Default for VectorReshapeBlock<I, O>
impl<I, O> Default for VectorReshapeBlock<I, O>
Sourceimpl<const IROWS: usize, const ICOLS: usize, const OROWS: usize, const OCOLS: usize, T> ProcessBlock for VectorReshapeBlock<Matrix<IROWS, ICOLS, T>, Matrix<OROWS, OCOLS, T>>where
T: Scalar,
impl<const IROWS: usize, const ICOLS: usize, const OROWS: usize, const OCOLS: usize, T> ProcessBlock for VectorReshapeBlock<Matrix<IROWS, ICOLS, T>, Matrix<OROWS, OCOLS, T>>where
T: Scalar,
Sourceimpl<T> ProcessBlock for VectorReshapeBlock<T, Matrix<1, 1, T>>where
T: Scalar,
impl<T> ProcessBlock for VectorReshapeBlock<T, Matrix<1, 1, T>>where
T: Scalar,